=== modified file 'drizzled/common_fwd.h'
--- drizzled/common_fwd.h	2011-03-29 12:45:08 +0000
+++ drizzled/common_fwd.h	2011-04-05 12:26:58 +0000
@@ -120,6 +120,7 @@
   class Schema;
   class SetVariableStatement;
   class Statement;
+  class Table;
   class Transaction;
   class TruncateTableStatement;
   class UpdateData;

=== modified file 'drizzled/open_tables_state.h'
--- drizzled/open_tables_state.h	2011-04-05 10:14:18 +0000
+++ drizzled/open_tables_state.h	2011-04-05 12:26:58 +0000
@@ -17,13 +17,15 @@
  *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-
 #pragma once
 
+#include <drizzled/common_fwd.h>
 #include <drizzled/lock.h>
 
 namespace drizzled {
 
+extern uint64_t g_refresh_version;
+
 /**
   Class that holds information about tables which were opened and locked
   by the thread.
@@ -66,25 +68,11 @@
   */
   void mark_temp_tables_as_free_for_reuse();
 
-protected:
-  void close_temporary_tables();
-
-public:
-  void close_temporary_table(Table *table);
-  
-private:
-  // The method below just handles the de-allocation of the table. In
-  // a better memory type world, this would not be needed.
-  void nukeTable(Table *table);
-
 public:
   /* Work with temporary tables */
   Table *find_temporary_table(const identifier::Table &identifier);
 
   void dumpTemporaryTableNames(const char *id);
-  int drop_temporary_table(const drizzled::identifier::Table &identifier);
-  bool rm_temporary_table(plugin::StorageEngine&, const identifier::Table&);
-  bool rm_temporary_table(const drizzled::identifier::Table &identifier, bool best_effort= false);
 
   virtual query_id_t getQueryId()  const= 0;
 

=== modified file 'drizzled/plugin/schema_engine.cc'
--- drizzled/plugin/schema_engine.cc	2011-04-04 22:17:21 +0000
+++ drizzled/plugin/schema_engine.cc	2011-04-05 12:26:58 +0000
@@ -255,7 +255,7 @@
 
       for (identifier::table::vector::iterator iter= set_of_identifiers.begin(); iter != set_of_identifiers.end(); iter++)
       {
-        if (session.open_tables.drop_temporary_table(*iter))
+        if (session.drop_temporary_table(*iter))
         {
           my_error(ER_TABLE_DROP, *iter);
           error= true;

=== modified file 'drizzled/refresh_version.h'
--- drizzled/refresh_version.h	2011-04-05 10:14:18 +0000
+++ drizzled/refresh_version.h	2011-04-05 12:26:58 +0000
@@ -25,7 +25,7 @@
 /** 
   Refresh value. We use to test this to find out if a refresh even has happened recently.
 */
-extern uint64_t g_refresh_version;  /* Increments on each reload */
+// extern uint64_t g_refresh_version;  /* Increments on each reload */
 
 } /* namespace drizzled */
 

=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2011-04-05 10:14:18 +0000
+++ drizzled/session.cc	2011-04-05 12:26:58 +0000
@@ -1736,7 +1736,7 @@
   Close all temporary tables created by 'CREATE TEMPORARY TABLE' for thread
 */
 
-void Open_tables_state::close_temporary_tables()
+void Session::close_temporary_tables()
 {
   Table *table;
   Table *tmp_next;
@@ -1756,7 +1756,7 @@
   unlink from session->temporary tables and close temporary table
 */
 
-void Open_tables_state::close_temporary_table(Table *table)
+void Session::close_temporary_table(Table *table)
 {
   if (table->getPrev())
   {
@@ -1792,7 +1792,7 @@
   If this is needed, use close_temporary_table()
 */
 
-void Open_tables_state::nukeTable(Table *table)
+void Session::nukeTable(Table *table)
 {
   plugin::StorageEngine& table_type= *table->getShare()->db_type();
   table->free_io_cache();
@@ -1980,19 +1980,19 @@
   might be an issue (lame engines).
 */
 
-bool Open_tables_state::rm_temporary_table(const identifier::Table &identifier, bool best_effort)
+bool Session::rm_temporary_table(const identifier::Table &identifier, bool best_effort)
 {
-  if (plugin::StorageEngine::dropTable(*static_cast<Session *>(this), identifier))
+  if (plugin::StorageEngine::dropTable(*this, identifier))
 		return false;
   if (not best_effort)
     errmsg_printf(error::WARN, _("Could not remove temporary table: '%s', error: %d"), identifier.getSQLPath().c_str(), errno);
   return true;
 }
 
-bool Open_tables_state::rm_temporary_table(plugin::StorageEngine& base, const identifier::Table &identifier)
+bool Session::rm_temporary_table(plugin::StorageEngine& base, const identifier::Table &identifier)
 {
   drizzled::error_t error;
-  if (plugin::StorageEngine::dropTable(*static_cast<Session *>(this), base, identifier, error))
+  if (plugin::StorageEngine::dropTable(*this, base, identifier, error))
 		return false;
   errmsg_printf(error::WARN, _("Could not remove temporary table: '%s', error: %d"), identifier.getSQLPath().c_str(), error);
   return true;

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2011-04-04 23:52:30 +0000
+++ drizzled/session.h	2011-04-05 12:26:58 +0000
@@ -78,7 +78,7 @@
  * session object.
  */
 
-class DRIZZLED_API Session : public Open_tables_state
+class DRIZZLED_API Session : private Open_tables_state
 {
 private:
   class impl_c;
@@ -1271,8 +1271,12 @@
    *
    * The lock will automaticaly be freed by close_thread_tables()
    */
-  bool openTablesLock(TableList *tables);
-  Table *open_temporary_table(const drizzled::identifier::Table &identifier, bool link_in_list= true);
+  void close_temporary_table(Table*);
+  int drop_temporary_table(const identifier::Table&);
+  bool openTablesLock(TableList*);
+  bool rm_temporary_table(plugin::StorageEngine&, const identifier::Table&);
+  bool rm_temporary_table(const identifier::Table &identifier, bool best_effort= false);
+  Table *open_temporary_table(const identifier::Table &identifier, bool link_in_list= true);
 
   int open_tables_from_list(TableList **start, uint32_t *counter, uint32_t flags= 0);
 
@@ -1346,7 +1350,9 @@
 
   bool arg_of_last_insert_id_function; // Tells if LAST_INSERT_ID(#) was called for the current statement
 private:
+  void close_temporary_tables();
   bool free_cached_table(boost::mutex::scoped_lock &scopedLock);
+  void nukeTable(Table*);
   drizzled::util::Storable* getProperty0(const std::string&);
   void setProperty0(const std::string&, drizzled::util::Storable*);
 

=== modified file 'drizzled/sql_base.cc'
--- drizzled/sql_base.cc	2011-04-05 10:14:18 +0000
+++ drizzled/sql_base.cc	2011-04-05 12:26:58 +0000
@@ -632,7 +632,7 @@
   @retval -1  the table is in use by a outer query
 */
 
-int Open_tables_state::drop_temporary_table(const drizzled::identifier::Table &identifier)
+int Session::drop_temporary_table(const drizzled::identifier::Table &identifier)
 {
   Table *table;
 
@@ -722,7 +722,7 @@
 {
   if (table->getShare()->getType())
   {
-    open_tables.close_temporary_table(table);
+    close_temporary_table(table);
   }
   else
   {

=== modified file 'drizzled/sql_insert.cc'
--- drizzled/sql_insert.cc	2011-04-04 23:52:30 +0000
+++ drizzled/sql_insert.cc	2011-04-05 12:26:58 +0000
@@ -1625,7 +1625,7 @@
             it preparable for open. But let us do close_temporary_table() here
             just in case.
           */
-          session->open_tables.drop_temporary_table(identifier);
+          session->drop_temporary_table(identifier);
         }
       }
     }

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-04-04 23:52:30 +0000
+++ drizzled/sql_table.cc	2011-04-05 12:26:58 +0000
@@ -138,7 +138,7 @@
     {
       identifier::Table tmp_identifier(table->getSchemaName(), table->getTableName());
 
-      error= session->open_tables.drop_temporary_table(tmp_identifier);
+      error= session->drop_temporary_table(tmp_identifier);
 
       switch (error) {
       case  0:
@@ -1365,7 +1365,7 @@
     /* Open table and put in temporary table list */
     if (not (session->open_temporary_table(identifier)))
     {
-      (void) session->open_tables.rm_temporary_table(identifier);
+      (void) session->rm_temporary_table(identifier);
       return error;
     }
   }
@@ -2089,12 +2089,12 @@
                                              is_engine_set);
       if (not was_created) // This is pretty paranoid, but we assume something might not clean up after itself
       {
-        (void) session->open_tables.rm_temporary_table(destination_identifier, true);
+        (void) session->rm_temporary_table(destination_identifier, true);
       }
       else if (not session->open_temporary_table(destination_identifier))
       {
         // We created, but we can't open... also, a hack.
-        (void) session->open_tables.rm_temporary_table(destination_identifier, true);
+        (void) session->rm_temporary_table(destination_identifier, true);
       }
       else
       {

=== modified file 'drizzled/statement/alter_table.cc'
--- drizzled/statement/alter_table.cc	2011-04-04 23:52:30 +0000
+++ drizzled/statement/alter_table.cc	2011-04-05 12:26:58 +0000
@@ -1162,7 +1162,7 @@
       if (new_table)
       {
         /* close_temporary_table() frees the new_table pointer. */
-        session->open_tables.close_temporary_table(new_table);
+        session->close_temporary_table(new_table);
       }
       else
       {
@@ -1206,7 +1206,7 @@
     }
 
     /* Remove link to old table and rename the new one */
-    session->open_tables.close_temporary_table(table);
+    session->close_temporary_table(table);
 
     /* Should pass the 'new_name' as we store table name in the cache */
     new_table->getMutableShare()->setIdentifier(new_table_identifier);

=== modified file 'drizzled/status_helper.cc'
--- drizzled/status_helper.cc	2011-04-05 10:14:18 +0000
+++ drizzled/status_helper.cc	2011-04-05 12:26:58 +0000
@@ -19,20 +19,17 @@
  */
 
 #include <config.h>
+#include "status_helper.h"
 #include <boost/lexical_cast.hpp>
-#include "status_helper.h"
+#include <drizzled/open_tables_state.h>
 #include <drizzled/set_var.h>
 #include <drizzled/drizzled.h>
 #include <plugin/myisam/myisam.h>
-
-#include <drizzled/refresh_version.h>
-
 #include <sstream>
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 extern time_t server_start_time;
 extern time_t flush_status_time;

